@@ -35,6 +35,12 @@ class BasePo(object):
         else:
             raise AttributeError("PO对象中的page属性未被初始化")
 
+    def get_url(self) -> str:
+        if self.__page.url.find("://") != -1:
+            return self.__page.url.split("?")[0]
+        else:
+            return self.__page.url
+
     @staticmethod
     def iss_current_page(page: Page, url: str) -> bool:
         if isinstance(page, Page):
@@ -92,7 +98,8 @@ class BasePo(object):
             raise RuntimeError(f"检查元素时发生错误: {str(e)}")
 
     @classmethod
-    async def handle_po_cookie_tip(cls, page: Any, logger: Logger, timeout: float = 3.0, selectors: List[str] = None) -> None:
+    async def handle_po_cookie_tip(cls, page: Any, logger: Logger, timeout: float = 3.0,
+                                   selectors: List[str] = None) -> None:
         selectors_inner: List[str] = [
             '//div[@id="isReadedCookie"]/button',
             '//button[@id="continue-btn"]/span[normalize-space(text())="同意"]'
@@ -108,5 +115,6 @@ class BasePo(object):
                 await cookie.click(button="left")
                 logger.info("【同意】按钮点击完成")
                 await asyncio.sleep(1)
+                return
             except (Exception,):
                 pass
